@@ -51,13 +51,7 @@ sub _parse_cpuinfo {
 
     my @flags = split /\s+/, $cpu{flags};
     my %flags = map { $_ => 1 } @flags;
-
-    my $up = Unix::Processors->new;
-
-    #foreach my $proc (@{$up->processors}) {
-    #    printf "id: %s, state: %s, clock: %s, type: %s\n",
-    #            $proc->id, $proc->state, $proc->clock, $proc->type;
-    #}
+    my $up    = Unix::Processors->new;
 
     return(
         processor_id                 => $cpu{processor},
@@ -72,10 +66,8 @@ sub _parse_cpuinfo {
         stepping                     => $cpu{stepping},
         number_of_cores              => $cpu{'cpu cores'} || $up->max_physical,
         number_of_logical_processors => $up->max_online,
-        L1_cache                     => {max_cache_size => $cpu{'cache size'}},
-        ( @flags ? (
-        flags => [ @flags ],
-        ) : ()),
+        L2_cache                     => {max_cache_size => $cpu{'cache size'}},
+        flags                        => @flags ? [ @flags ] : undef,
     );
 }
 
